@@ -15,6 +15,7 @@ MQTT_PASSWORD: str = config['MQTT_PASSWORD']
 MQTT_BASE_TOPIC: str = config['MQTT_BASE_TOPIC']
 SERIAL_PORTS_MAP: list = config['SERIAL_PORTS_MAP']
 LED_MAP: list = config['LED_MAP']
+FRAME_TIME: float = config['FRAME_TIME']
 
 global state, r, g, b, brightness, effect, effector, led, effects_list
 
@@ -113,7 +114,7 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                         r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
                 elif effect >= 2:
                     effector = led_effects.effects[effect]['class'](
-                        frame_time=0.1, led=led, brightness=brightness, r=r, g=g, b=b)
+                        frame_time=FRAME_TIME, led=led, brightness=brightness, r=r, g=g, b=b)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/state",
                        "on" if state else "off")
     elif topic == MQTT_BASE_TOPIC+"/control/brightness":
@@ -160,12 +161,11 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                     led.turn_off()
                 elif effect >= 2 and state:
                     effector = led_effects.effects[i]['class'](
-                        frame_time=0.1, led=led, brightness=brightness, r=r, g=g, b=b)
+                        frame_time=FRAME_TIME, led=led, brightness=brightness, r=r, g=g, b=b)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
                        led_effects.effects[effect]['name'])
     elif topic == MQTT_BASE_TOPIC+"/control/exit":
         sys.exit(0)
-    #TODO Input Validation, 0<=data[0]<=num_leds
     elif topic == MQTT_BASE_TOPIC+"/control/program":
         if effect == 1:
             datas = json.loads(payload)
